==> maraca_0.6.tar.gz: maraca/R/aaa.R <==
# Ignored NSE variables in devtools::check
utils::globalVariables("time")
utils::globalVariables("n")
utils::globalVariables("n.event")
utils::globalVariables("x")
utils::globalVariables("y")
utils::globalVariables("strata")
utils::globalVariables("surv")
utils::globalVariables("proportion")
utils::globalVariables("km.y")
utils::globalVariables("km.start")
utils::globalVariables("original")
utils::globalVariables("ordered")
utils::globalVariables("arm")
utils::globalVariables("outcome")
utils::globalVariables("violiny")
utils::globalVariables("violinx")
utils::globalVariables("adjusted.time")
utils::globalVariables("tte_outcomes")
utils::globalVariables("continuous_outcome")
utils::globalVariables("treatments")
utils::globalVariables("fixed_followup_days")
utils::globalVariables("average")
utils::globalVariables("value")
utils::globalVariables("percentage")
utils::globalVariables("name")
utils::globalVariables(".env")
utils::globalVariables("separation")
utils::globalVariables("gap")
utils::globalVariables("median")
utils::globalVariables("ecdf_values")
utils::globalVariables("group")
utils::globalVariables("xmin_final")
utils::globalVariables("xmin")
utils::globalVariables("xlower")
utils::globalVariables("xmiddle")
utils::globalVariables("xupper")
utils::globalVariables("xmax")
utils::globalVariables("xmax_final")
utils::globalVariables("outliers")
utils::globalVariables("GROUP")
utils::globalVariables("TRTP")
utils::globalVariables("WIN")
utils::globalVariables("LOSS")
utils::globalVariables("TIE")
utils::globalVariables("TOTAL")
utils::globalVariables("WIN_A")
utils::globalVariables("WIN_P")
utils::globalVariables("TIE_A")

==> maraca_0.7.1.tar.gz: maraca/R/aaa.R <==
# Ignored NSE variables in devtools::check
utils::globalVariables("time")
utils::globalVariables("n")
utils::globalVariables("n.event")
utils::globalVariables("x")
utils::globalVariables("y")
utils::globalVariables("xend")
utils::globalVariables("yend")
utils::globalVariables("strata")
utils::globalVariables("surv")
utils::globalVariables("proportion")
utils::globalVariables("km.y")
utils::globalVariables("km.start")
utils::globalVariables("original")
utils::globalVariables("ordered")
utils::globalVariables("arm")
utils::globalVariables("outcome")
utils::globalVariables("violiny")
utils::globalVariables("violinx")
utils::globalVariables("adjusted.time")
utils::globalVariables("tte_outcomes")
utils::globalVariables("step_values")
utils::globalVariables("type")
utils::globalVariables("t_cdf")
utils::globalVariables("continuous_outcome")
utils::globalVariables("treatments")
utils::globalVariables("fixed_followup_days")
utils::globalVariables("average")
utils::globalVariables("estimate")
utils::globalVariables("value")
utils::globalVariables("percentage")
utils::globalVariables("count")
utils::globalVariables(".env")
utils::globalVariables("separation")
utils::globalVariables("gap")
utils::globalVariables("median")
utils::globalVariables("ecdf_values")
utils::globalVariables("group")
utils::globalVariables("xmin_final")
utils::globalVariables("xmin")
utils::globalVariables("xlower")
utils::globalVariables("xmiddle")
utils::globalVariables("xupper")
utils::globalVariables("xmax")
utils::globalVariables("xmax_final")
utils::globalVariables("outliers")
utils::globalVariables("GROUP")
utils::globalVariables("TRTP")
utils::globalVariables("WIN")
utils::globalVariables("LOSS")
utils::globalVariables("TIE")
utils::globalVariables("TOTAL")
utils::globalVariables("WIN_A")
utils::globalVariables("WIN_P")
utils::globalVariables("TIE_A")
utils::globalVariables("linetype")
utils::globalVariables("method")
utils::globalVariables("UCL")
utils::globalVariables("LCL")
utils::globalVariables("tot")
